# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/assetise/lcc_plan/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Assetise\\LccPlan\\": "packages/assetise/lcc_plan/src",
            "Assetise\\LccPlan\\Seeders\\": "packages/assetise/lcc_plan/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Assetise\LccPlan\Providers\LccPlanServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'LccPlan'  => Assetise\LccPlan\Facades\LccPlan::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Assetise\\LccPlan\\Seeders\\LccPlanTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Assetise\LccPlan\Providers\LccPlanServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Assetise\LccPlan\Providers\LccPlanServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Assetise\LccPlan\Providers\LccPlanServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/lcc_plan/{modulename}

**User**

    http://path-to-route-folder/user/lcc_plan/{modulename}

**Public**

    http://path-to-route-folder/lcc_plans


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/lcc_plan/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/lcc_plan/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/lcc_plan/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/lcc_plan/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/lcc_plan/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/lcc_plan/{modulename}/{slug}
    METHOD: GET