<?php

namespace Assetise\LccPlan\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetise\LccPlan\Http\Requests\LccPlanRequest;
use Assetise\LccPlan\Models\LccPlan;

/**
 * Admin web controller class.
 */
class LccPlanWorkflowController extends BaseController
{

    /**
     * Workflow controller function for lcc_plan.
     *
     * @param Model   $lcc_plan
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(LccPlanRequest $request, LccPlan $lcc_plan, $step)
    {

        try {

            $lcc_plan->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('lcc_plan::lcc_plan.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/lcc_plan/lcc_plan/' . $lcc_plan->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/lcc_plan/lcc_plan/' . $lcc_plan->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for lcc_plan.
     *
     * @param Model   $lcc_plan
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(LccPlan $lcc_plan, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $lcc_plan->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('lcc_plan::lcc_plan.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lcc_plan::admin.lcc_plan.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lcc_plan::admin.lcc_plan.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('lcc_plan::admin.lcc_plan.message', $data)->render();

        }

    }
}
