<?php

namespace Assetise\LccPlan\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Assetise\LccPlan\Models\LccPlan;

class LccPlanPolicy
{

    /**
     * Determine if the given user can view the lcc_plan.
     *
     * @param UserPolicyInterface $authUser
     * @param LccPlan $lcc_plan
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, LccPlan $lcc_plan)
    {
        if ($authUser->canDo('lcc_plan.lcc_plan.view') && $authUser->isAdmin()) {
            return true;
        }

        return $lcc_plan->user_id == user_id() && $lcc_plan->user_type == user_type();
    }

    /**
     * Determine if the given user can create a lcc_plan.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('lcc_plan.lcc_plan.create');
    }

    /**
     * Determine if the given user can update the given lcc_plan.
     *
     * @param UserPolicyInterface $authUser
     * @param LccPlan $lcc_plan
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, LccPlan $lcc_plan)
    {
        if ($authUser->canDo('lcc_plan.lcc_plan.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $lcc_plan->user_id == user_id() && $lcc_plan->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given lcc_plan.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, LccPlan $lcc_plan)
    {
        return $lcc_plan->user_id == user_id() && $lcc_plan->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given lcc_plan.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, LccPlan $lcc_plan)
    {
        if ($authUser->canDo('lcc_plan.lcc_plan.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given lcc_plan.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, LccPlan $lcc_plan)
    {
        if ($authUser->canDo('lcc_plan.lcc_plan.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
