<?php

namespace Assetise\LccPlan\Providers;

use Illuminate\Support\ServiceProvider;
use Assetise\LccPlan\LccPlans;

class LccPlanServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'lcc_plan');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'lcc_plan');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        // $this->registerCommands();

        $this->app->register(\Assetise\LccPlan\Providers\AuthServiceProvider::class);
        $this->app->register(\Assetise\LccPlan\Providers\RouteServiceProvider::class);
        // $this->app->register(\Assetise\LccPlan\Providers\EventServiceProvider::class);
        // $this->app->register(\Assetise\LccPlan\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('assetise.lcc_plan', function($app)
        {
            return $this->app->make(LccPlans::class);
        });
    }



    /**
     * Merges user's and lcc_plan's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'assetise.lcc_plan'
        );
        
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/lcc_plan.php', 'assetise.lcc_plan.lcc_plan'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Assetise\LccPlan\Commands\LccPlan::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['assetise.lcc_plan'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('assetise/lcc_plan')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/lcc_plan')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/lcc_plan')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
