<?php

namespace Assetise\LccPlan\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Assetise\LccPlan\Models\LccPlan;

class LccPlanAction
{
    /**
     * Perform the complete action.
     *
     * @param LccPlan $lcc_plan
     *
     * @return LccPlan
     */
    public function complete(LccPlan $lcc_plan)
    {
        try {
            $lcc_plan->status = 'complete';
            return $lcc_plan->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param LccPlan $lcc_plan
     *
     * @return LccPlan
     */public function verify(LccPlan $lcc_plan)
    {
        try {
            $lcc_plan->status = 'verify';
            return $lcc_plan->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param LccPlan $lcc_plan
     *
     * @return LccPlan
     */public function approve(LccPlan $lcc_plan)
    {
        try {
            $lcc_plan->status = 'approve';
            return $lcc_plan->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param LccPlan $lcc_plan
     *
     * @return LccPlan
     */public function publish(LccPlan $lcc_plan)
    {
        try {
            $lcc_plan->status = 'publish';
            return $lcc_plan->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param LccPlan $lcc_plan
     *
     * @return LccPlan
     */
    public function archive(LccPlan $lcc_plan)
    {
        try {
            $lcc_plan->status = 'archive';
            return $lcc_plan->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param LccPlan $lcc_plan
     *
     * @return LccPlan
     */
    public function unpublish(LccPlan $lcc_plan)
    {
        try {
            $lcc_plan->status = 'unpublish';
            return $lcc_plan->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
