<?php

namespace Assetise\LccPlan\Workflow;

use Assetise\LccPlan\Models\LccPlan;
use Validator;

class LccPlanValidator
{

    /**
     * Determine if the given lcc_plan is valid for complete status.
     *
     * @param LccPlan $lcc_plan
     *
     * @return bool / Validator
     */
    public function complete(LccPlan $lcc_plan)
    {
        return Validator::make($lcc_plan->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given lcc_plan is valid for verify status.
     *
     * @param LccPlan $lcc_plan
     *
     * @return bool / Validator
     */
    public function verify(LccPlan $lcc_plan)
    {
        return Validator::make($lcc_plan->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given lcc_plan is valid for approve status.
     *
     * @param LccPlan $lcc_plan
     *
     * @return bool / Validator
     */
    public function approve(LccPlan $lcc_plan)
    {
        return Validator::make($lcc_plan->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given lcc_plan is valid for publish status.
     *
     * @param LccPlan $lcc_plan
     *
     * @return bool / Validator
     */
    public function publish(LccPlan $lcc_plan)
    {
        return Validator::make($lcc_plan->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given lcc_plan is valid for archive status.
     *
     * @param LccPlan $lcc_plan
     *
     * @return bool / Validator
     */
    public function archive(LccPlan $lcc_plan)
    {
        return Validator::make($lcc_plan->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given lcc_plan is valid for unpublish status.
     *
     * @param LccPlan $lcc_plan
     *
     * @return bool / Validator
     */
    public function unpublish(LccPlan $lcc_plan)
    {
        return Validator::make($lcc_plan->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
